/*
Copyright 2010-2012 Sergey Levin


This file is part of crosti.

Crosti is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Crosti is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with crosti.  If not, see <http://www.gnu.org/licenses/>.
*/


#include "cschemeviewer.h"
#include "cviewportwatcher.h"


CSchemeViewer::CSchemeViewer(View* schm,QWidget *parent):CViewer(parent),
    scrollArea(new CScrollArea),
    scheme(schm)
{
    ViewPortWatcher = new CViewPortWatcher(reinterpret_cast<QScrollArea*>(scrollArea), this);

    scrollArea->setFrameShape(QFrame::NoFrame);
    scrollArea->setBackgroundRole(QPalette::Light);
    scrollArea->setWidget(scheme);
    layout->insertWidget(0,scrollArea);

    connect(scaleBar, SIGNAL(scaleChanged(qreal)) ,scheme, SLOT(setScale(qreal)));
    connect(scaleBar, SIGNAL(scaleChanged(qreal)), ViewPortWatcher, SLOT(setScale(qreal)));
    connect(scrollArea, SIGNAL(sizeChanged()), ViewPortWatcher, SLOT(viewPortChanged()));
}



CSchemeViewer::~CSchemeViewer()
{
  delete scrollArea;
}



void CSchemeViewer::reset()
{
    scheme->setScale(1);
    scaleBar->ui.scaleSB->setValue(scaleBar->scaleDefault());
    scrollArea->horizontalScrollBar()->setValue(0);
    scrollArea->verticalScrollBar()->setValue(0);

    ViewPortWatcher->setSceneRect(QRect(QPoint(), scheme->sizeHint()));

    scheme->update();
}
